;********************************************
; FRI FOR FRANSK! GFX-RUTINES               *
; Marc Klemp (c) 2003, 2004, 2005           *
;********************************************

VRAMWriteStart:                                  ; hl = VRAM address.

   ld a, l                                       ; These two writes to the VDP Control Port
   out ($BF), a                                  ; means that there now will be written to the
   ld a, h                                       ; VRAM, starting from the address in hl. The
   xor $40                                       ; value is xor'ed with $40 to set the "write"-bit.
   out ($BF), a
   ret

ClearVRAM:                                       ; Thanks to Mike Gordon.

   push bc
   push af

   ld hl, $0000
   call VRAMWriteStart

   ld bc, $4000
   ld a, $00
   out ($BE), a

ClearVRAM_Loop:
   dec c
   jr nz, ClearVRAM_Loop

   dec b
   jr nz, ClearVRAM_Loop

   pop af
   pop bc

   ret

DisableSprites:

   push hl
   push af

   ld hl, $3F00
   call VRAMWriteStart
   ld a, 208                                    ; When the VDP encounters a sprite with y position 208, no more sprites will be drawn (including that one).
   out ($BE), a

   pop af
   pop hl

   ret

ClearNameTable:			                 ; Fills the Name Table with $00.

   push hl
   push bc
   push af

   ld hl, $3800
   call VRAMWriteStart

   ld bc, $400

ClearNameTable_Loop:
   ld a, $00
   out ($BE), a
   ld a, $00
   out ($BE), a

   dec c
   jr nz, ClearNameTable_Loop

   dec b
   jr nz, ClearNameTable_Loop

   pop af
   pop bc
   pop hl

   ret

 SetupVDP_Standard:

   push af

   ld a, %00000100
   out ($BF), a
   ld a, $80                   ; ...register 0
   out ($BF), a

   ld a, %11111111
   out ($BF), a
   ld a, $82
   out ($BF), a

   ld a, %11111111
   out ($BF), a
   ld a, $83
   out ($BF), a

   ld a, %11111111
   out ($BF), a
   ld a, $84
   out ($BF), a

   ld a, %11111111
   out ($BF), a
   ld a, $85
   out ($BF), a

   ld a, %11111111
   out ($BF), a
   ld a, $86
   out ($BF), a

   ld a, %00000000              ; Backdrop color (defined by the low 4 bits)
   out ($BF), a
   ld a, $87
   out ($BF), a

   ld a, %00000000
   out ($BF), a
   ld a, $88
   out ($BF), a

   ld a, %00000000
   out ($BF), a
   ld a, $89
   out ($BF), a

   ld a, %00000000
   out ($BF), a
   ld a, $8A
   out ($BF), a

   pop af

   ret

TurnOnVDP:

   push af

   ld a, %11100100                               ; Activate Display and VBlank Interrupts.
   out ($BF), a
   ld a, %10000001		                 ; The above is written to the VDP register 1.
   out ($BF), a

   pop af

   ret

LoadPalette:                                     ; hl = address pointing to the start of the palette.

   push bc
   push af

   ld b, $20                                     ; b = $20 = 32, as there can be 32 colors in the CRAM.
   ld c, $BE                                     ; c = $BE which is the VDP Data Port.
   ld a, $00
   out ($BF), a
   ld a, $C0
   out ($BF), a
   otir

   pop af
   pop bc

   ret

Load3BitsTilesToVRAM:

   push hl
   push de

   ld hl, GFXTitelTiles_Data
   ld d, $CB+1
   ld e, 8

VRAM3BitsTilesRepeat:

   ld a, (hl)
   out ($BE), a
   inc hl
   ld a, (hl)
   out ($BE), a
   inc hl
   ld a, (hl)
   out ($BE), a
   inc hl

   ld a, $00
   out ($BE), a

   dec e
   jp nz, VRAM3BitsTilesRepeat

   ld e, 8

   dec d
   jp nz, VRAM3BitsTilesRepeat

   pop de
   pop hl
   ret

LoadTilesFromVRAMToNameTable:

   push hl
   push de
   push af

   ld hl, $3800
   call VRAMWriteStart
   ld hl, GFXTitelBuild_Data
   ld de, (GFXTitelBuild_DataEnd)-(GFXTitelBuild_Data)

TilesFromVRAMToNameTableRepeat:
   ld a, (hl)
   out ($BE), a
   inc hl

   dec e
   jp nz, TilesFromVRAMToNameTableRepeat
   dec d
   jp nz, TilesFromVRAMToNameTableRepeat

   pop af
   pop de
   pop hl

   ret

ChangePalette:

   push hl
   push af

   ld hl, $CC01
   ld a, (hl)
   cp %00001111
   jp z, Color1
   ld a, %00001111
   ld (hl), a

   jp EndChangePalette

Color1:
   ld a, %00001000
   ld (hl), a

EndChangePalette:
   ld a, $00
   out ($BF), a
   ld a, $C0
   out ($BF), a

   ld a, (hl)
   out ($BE), a

   pop af
   pop hl

   ld a, $20

   ret
